WLabKit
====

**This is a toolkit to handle bio-data from WeiBin Lab.**

Similar data processing tasks occur frequently in my daily work though
these tasks are not complicated. To avoid change the code repeatedly, I
set up this project for the convenience of laboratory members and
others.

Installation
------------

Binary installers for the latest released version are available at the
Python Package Index (PyPI) and on Conda.

.. code:: shell

   conda install wlabkit

.. code:: shell

   pip install wlabkit

Subcommands
-----------

-  **getseq**

get target sequences from a header list.

Contact
-------

If you have any problems, don’t hesitate to contact me.
gavinchou64@gmail.com
